package net.wanji.opt.service.impl;

import lombok.extern.slf4j.Slf4j;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.enums.StrategyAndMetricsEnum;
import net.wanji.common.enums.TurnConvertEnum;
import net.wanji.databus.dao.entity.BaseCrossDirInfoPO;
import net.wanji.databus.dao.mapper.*;
import net.wanji.databus.po.*;
import net.wanji.opt.bo.BottomCurveBO;
import net.wanji.opt.bo.BottomMenuBO;
import net.wanji.opt.service.MainlineEvaluateService;
import net.wanji.opt.vo.MainlineEvaluateBottomCurveVO;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author Kent HAN
 * @date 2023/9/19 15:24
 */
@Slf4j
@Service
public class MainlineEvaluateServiceImpl implements MainlineEvaluateService {
    private final BaseCrossDirInfoMapper baseCrossDirInfoMapper;
    private final BaseCrossTurnInfoMapper baseCrossTurnInfoMapper;
    private final LaneInfoMapper laneInfoMapper;
    private final CrossDirDataHistMapper crossDirDataHistMapper;
    private final CrossDataHistMapper crossDataHistMapper;
    private final CrossTurnDataHistMapper crossTurnDataHistMapper;
    private final CrossLaneDataHistMapper crossLaneDataHistMapper;

    SimpleDateFormat hourMinuteFormat = new SimpleDateFormat("HH:mm");
    SimpleDateFormat dateHourMinuteFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm");

    public MainlineEvaluateServiceImpl(@Qualifier("baseCrossDirInfoMapper") BaseCrossDirInfoMapper baseCrossDirInfoMapper,
                                       @Qualifier("baseCrossTurnInfoMapper") BaseCrossTurnInfoMapper baseCrossTurnInfoMapper,
                                       CrossBaseLaneInfoMapper crossBaseLaneInfoMapper,
                                       @Qualifier("laneInfoMapper") LaneInfoMapper laneInfoMapper,
                                       CrossDirDataHistMapper crossDirDataHistMapper, CrossDataHistMapper crossDataHistMapper, CrossTurnDataHistMapper crossTurnDataHistMapper, CrossLaneDataHistMapper crossLaneDataHistMapper) {
        this.baseCrossDirInfoMapper = baseCrossDirInfoMapper;
        this.baseCrossTurnInfoMapper = baseCrossTurnInfoMapper;
        this.laneInfoMapper = laneInfoMapper;
        this.crossDirDataHistMapper = crossDirDataHistMapper;
        this.crossDataHistMapper = crossDataHistMapper;
        this.crossTurnDataHistMapper = crossTurnDataHistMapper;
        this.crossLaneDataHistMapper = crossLaneDataHistMapper;
    }

    @Override
    public List<String> bottomMenu(BottomMenuBO bo) {
        String crossId = bo.getCrossId();
        Integer scope = bo.getScope();

        if (scope == 1) {
            return buildDirMenu(crossId);
        } else if (scope == 2) {
            return buildTurnMenu(crossId);
        } else if (scope == 3) {
            return buildLaneMenu(crossId);
        }

        return null;
    }

    @Override
    public List<MainlineEvaluateBottomCurveVO> bottomCurve(BottomCurveBO bo) throws ParseException {
        String crossId = bo.getCrossId();
        Integer scope = bo.getScope();
        List<String> scopeList = bo.getScopeList();
        Integer minutes = bo.getMinutes();
        String metricCode = bo.getMetricCode();
        Date startTime = bo.getStartTime();
        Date endTime = bo.getEndTime();

        if (scope != 1 && Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.LOAD_BALANCE.getCode())) {
            throw new RuntimeException("只有路口级别可选择负载均衡度");
        }

        List<String> timeList = buildTimeList(startTime, endTime, minutes);
        List<MainlineEvaluateBottomCurveVO> res = new ArrayList<>();


        int startTimeStamp = (int)(startTime.getTime() / 1000);
        int endTimeStamp = (int)(endTime.getTime() / 1000);

        if (scope == 0) { // 路口
            // 查询路口该时段内的所有数据
            List<CrossDataHistPO> crossPOList = crossDataHistMapper.selectByCrossIdAndStartEnd(
                    crossId, startTimeStamp, endTimeStamp);
            for (String timeStr : timeList) {
                Date startDatetime = calcDate(timeStr, startTime);
                MainlineEvaluateBottomCurveVO vo = new MainlineEvaluateBottomCurveVO();
                vo.setMetricTime(timeStr);

                // 计算 endDatetime
                Calendar calendar = Calendar.getInstance();
                calendar.setTime(startDatetime);
                calendar.add(Calendar.MINUTE, minutes);
                Date endDatetime = calendar.getTime();
                // 转换为 10 位时间戳
                int startTimeStampPart = (int)(startDatetime.getTime() / 1000);
                int endTimeStampPart = (int)(endDatetime.getTime() / 1000);
                // 使用流式编程进行筛选
                List<CrossDataHistPO> filteredList = crossPOList.stream()
                        .filter(po -> po.getBatchTime() >= startTimeStampPart && po.getBatchTime() <= endTimeStampPart)
                        .collect(Collectors.toList());
                if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.NO_STOP_RATE.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getNoStopRate)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v * 100));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_RATE.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getOneStopRate)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v * 100));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_DELAY.getCode())) {
                    double v = filteredList.stream()
                            .mapToInt(CrossDataHistPO::getDelayTime)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.MAX_QUEUE_LENGTH.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getQueueLength)
                            .max()
                            .orElse(0.0);
                    int round = (int) (Math.round(v));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_TIMES.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getStopTimes)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_SPEED.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getSpeed)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.GREEN_LIGHT_EFFICIENCY.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getGreenLightEfficiency)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v * 100));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.SATURATION.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getSturation)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v * 100));
                    vo.setValue(round);
                } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.LOAD_BALANCE.getCode())) {
                    double v = filteredList.stream()
                            .mapToDouble(CrossDataHistPO::getLoadBalance)
                            .average()
                            .orElse(0.0);
                    int round = (int) (Math.round(v));
                    vo.setValue(round);
                }

                res.add(vo);
            }
        } else if (scope == 1) { // 进口道
            // 查询各进口道该时段内的所有数据
            List<CrossDirDataHistPO> dirPOList = crossDirDataHistMapper.selectByCrossIdAndStartEnd(
                    crossId, startTimeStamp, endTimeStamp);

            for (String timeStr : timeList) {
                Date startDatetime = calcDate(timeStr, startTime);

                for (String dirStr : scopeList) {
                    int index = dirStr.indexOf("进口");
                    String dirName = dirStr.substring(0, index);
                    Integer dirCode = BaseEnum.SignalDirectionEnum.getCodeByName(dirName);

                    MainlineEvaluateBottomCurveVO vo = new MainlineEvaluateBottomCurveVO();
                    vo.setMetricTime(timeStr);
                    vo.setScopeName(dirStr);

                    // 计算 endDatetime
                    Calendar calendar = Calendar.getInstance();
                    calendar.setTime(startDatetime);
                    calendar.add(Calendar.MINUTE, minutes);
                    Date endDatetime = calendar.getTime();
                    // 转换为 10 位时间戳
                    int startTimeStampPart = (int)(startDatetime.getTime() / 1000);
                    int endTimeStampPart = (int)(endDatetime.getTime() / 1000);
                    // 使用流式编程进行筛选
                    List<CrossDirDataHistPO> filteredList = dirPOList.stream()
                            .filter(po -> po.getDirType().equals(dirCode))
                            .filter(po -> po.getInOutType().equals(1))
                            .filter(po -> po.getBatchTime() >= startTimeStampPart
                                    && po.getBatchTime() <= endTimeStampPart)
                            .collect(Collectors.toList());
                    if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.NO_STOP_RATE.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossDirDataHistPO::getNoStopRate)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_RATE.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossDirDataHistPO::getOneStopRate)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_DELAY.getCode())) {
                        double v = filteredList.stream()
                                .mapToInt(CrossDirDataHistPO::getDelayTime)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.MAX_QUEUE_LENGTH.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossDirDataHistPO::getQueueLength)
                                .max()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_TIMES.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossDirDataHistPO::getStopTimes)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_SPEED.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossDirDataHistPO::getSpeed)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.GREEN_LIGHT_EFFICIENCY.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossDirDataHistPO::getGreenLightEfficiency)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.SATURATION.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossDirDataHistPO::getSturation)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    }

                    res.add(vo);
                }
            }
        } else if (scope == 2) { // 方向
            // 查询各方向该时段内的所有数据
            List<CrossTurnDataHistPO> dirPOList = crossTurnDataHistMapper.selectByCrossId (
                    crossId, endTimeStamp, startTimeStamp);

            for (String timeStr : timeList) {
                Date startDatetime = calcDate(timeStr, startTime);

                for (String turnStr : scopeList) {
                    int index = turnStr.indexOf("进口");
                    String dirName = turnStr.substring(0, index);
                    Integer dirCode = BaseEnum.SignalDirectionEnum.getCodeByName(dirName);
                    String turnName = turnStr.substring(index + 2);
                    String turnCode = TurnConvertEnum.getCodeByDesc(turnName);

                    MainlineEvaluateBottomCurveVO vo = new MainlineEvaluateBottomCurveVO();
                    vo.setMetricTime(timeStr);
                    vo.setScopeName(turnStr);

                    // 计算 endDatetime
                    Calendar calendar = Calendar.getInstance();
                    calendar.setTime(startDatetime);
                    calendar.add(Calendar.MINUTE, minutes);
                    Date endDatetime = calendar.getTime();
                    // 转换为 10 位时间戳
                    int startTimeStampPart = (int)(startDatetime.getTime() / 1000);
                    int endTimeStampPart = (int)(endDatetime.getTime() / 1000);
                    // 使用流式编程进行筛选
                    List<CrossTurnDataHistPO> filteredList = dirPOList.stream()
                            .filter(po -> po.getInDir().equals(dirCode))
                            .filter(po -> po.getTurnType().equals(turnCode))
                            .filter(po -> po.getBatchTime() >= startTimeStampPart
                                    && po.getBatchTime() <= endTimeStampPart)
                            .collect(Collectors.toList());
                    if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.NO_STOP_RATE.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossTurnDataHistPO::getNoStopRate)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_RATE.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossTurnDataHistPO::getOneStopRate)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_DELAY.getCode())) {
                        double v = filteredList.stream()
                                .mapToInt(CrossTurnDataHistPO::getDelayTime)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.MAX_QUEUE_LENGTH.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossTurnDataHistPO::getQueueLength)
                                .max()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_TIMES.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossTurnDataHistPO::getStopTimes)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_SPEED.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossTurnDataHistPO::getSpeed)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.GREEN_LIGHT_EFFICIENCY.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossTurnDataHistPO::getGreenLightEfficiency)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.SATURATION.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossTurnDataHistPO::getSturation)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    }

                    res.add(vo);
                }
            }
        } else if (scope == 3) { // 车道
            // 查询各车道该时段内的所有数据
            List<CrossLaneDataHistPOExt> lanePOList = crossLaneDataHistMapper.selectByCrossId(
                    crossId, endTimeStamp, startTimeStamp);

            for (String timeStr : timeList) {
                Date startDatetime = calcDate(timeStr, startTime);

                for (String laneStr : scopeList) {
                    int indexOfJinKou = laneStr.indexOf("进口");
                    int indexOfCheDao = laneStr.indexOf("车道");
                    // 截取"进口"之前的部分
                    String dirName = laneStr.substring(0, indexOfJinKou);
                    // 截取"车道"之前的数字部分
                    String laneSortStr = laneStr.substring(indexOfCheDao - 2, indexOfCheDao);

                    Integer dirCode = BaseEnum.SignalDirectionEnum.getCodeByName(dirName);
                    Integer laneSort = Integer.parseInt(laneSortStr);

                    MainlineEvaluateBottomCurveVO vo = new MainlineEvaluateBottomCurveVO();
                    vo.setMetricTime(timeStr);
                    vo.setScopeName(laneStr);

                    // 计算 endDatetime
                    Calendar calendar = Calendar.getInstance();
                    calendar.setTime(startDatetime);
                    calendar.add(Calendar.MINUTE, minutes);
                    Date endDatetime = calendar.getTime();
                    // 转换为 10 位时间戳
                    int startTimeStampPart = (int)(startDatetime.getTime() / 1000);
                    int endTimeStampPart = (int)(endDatetime.getTime() / 1000);
                    // 筛选方向、车道序号
                    List<CrossLaneDataHistPOExt> filteredList = lanePOList.stream()
                            .filter(po -> po.getDir().equals(dirCode))
                            .filter(po -> po.getSort().equals(laneSort))
                            .filter(po -> po.getBatchTime() >= startTimeStampPart
                                    && po.getBatchTime() <= endTimeStampPart)
                            .collect(Collectors.toList());

                    if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.NO_STOP_RATE.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossLaneDataHistPOExt::getNoStopRate)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_RATE.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossLaneDataHistPOExt::getOneStopRate)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_DELAY.getCode())) {
                        double v = filteredList.stream()
                                .mapToInt(CrossLaneDataHistPOExt::getDelayTime)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.MAX_QUEUE_LENGTH.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossLaneDataHistPOExt::getQueueLength)
                                .max()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.STOP_TIMES.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossLaneDataHistPOExt::getStopTimes)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.AVERAGE_SPEED.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossLaneDataHistPOExt::getSpeed)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.GREEN_LIGHT_EFFICIENCY.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossLaneDataHistPOExt::getGreenLightEfficiency)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    } else if (Objects.equals(metricCode, StrategyAndMetricsEnum.Metrics.SATURATION.getCode())) {
                        double v = filteredList.stream()
                                .mapToDouble(CrossLaneDataHistPOExt::getSturation)
                                .average()
                                .orElse(0.0);
                        int round = (int) (Math.round(v * 100));
                        vo.setValue(round);
                    }

                    res.add(vo);
                }
            }
        }


        return res;
    }

    private Date calcDate(String timeStr, Date startTime) throws ParseException {
        // 使用 Calendar 来获取年、月、日信息
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(startTime);
        // 使用 SimpleDateFormat 来获取时和分
        Date time = hourMinuteFormat.parse(timeStr);
        Calendar timeCal = Calendar.getInstance();
        timeCal.setTime(time);
        // 组合两者
        calendar.set(Calendar.HOUR_OF_DAY, timeCal.get(Calendar.HOUR_OF_DAY));
        calendar.set(Calendar.MINUTE, timeCal.get(Calendar.MINUTE));
        calendar.set(Calendar.SECOND, 0);
        calendar.set(Calendar.MILLISECOND, 0);
        // 转换回 Date 对象
        Date startDatetime = calendar.getTime();
        return startDatetime;
    }

    private List<String> buildTimeList(Date startTime, Date endTime, Integer minutes) {
        // 用于存储时间区间的列表
        List<String> timeList = new ArrayList<>();

        Calendar cal = Calendar.getInstance();
        cal.setTime(startTime);

        while (cal.getTime().before(endTime) || cal.getTime().equals(endTime)) {
            String formattedTime = hourMinuteFormat.format(cal.getTime());
            timeList.add(formattedTime);
            // 增加指定分钟数
            cal.add(Calendar.MINUTE, minutes);
        }
        return timeList;
    }

    public static String formatTime(int totalMinutes) {
        int hours = totalMinutes / 60;
        int minutes = totalMinutes % 60;
        return String.format("%02d:%02d", hours, minutes);
    }

    private List<String> buildLaneMenu(String crossId) {
        List<BaseCrossDirInfoPO> poList = baseCrossDirInfoMapper.selectByCrossId(crossId);
        List<BaseCrossDirInfoPO> dirList = poList.stream()
                .filter(po -> po.getInOutType() == 1)
                .collect(Collectors.toList());
        List<String> res = new ArrayList<>();
        for (BaseCrossDirInfoPO dirPo : dirList) {
            Integer dirType = dirPo.getDirType();
            String dirName = BaseEnum.SignalDirectionEnum.getNameByCode(dirType);

            List<LaneInfoPO> laneList = laneInfoMapper.selectInDirByCrossIdAndDir(crossId, dirType);
            for (LaneInfoPO lanePO : laneList) {
                Integer turn = lanePO.getTurn();
                String turnDesc = TurnConvertEnum.getDescByKey(turn);
                Integer sort = lanePO.getSort();
                res.add(dirName + "进口" + turnDesc + sort + "车道");
            }
        }
        return res;
    }

    private List<String> buildTurnMenu(String crossId) {
        List<BaseCrossDirInfoPO> poList = baseCrossDirInfoMapper.selectByCrossId(crossId);
        List<BaseCrossDirInfoPO> dirList = poList.stream()
                .filter(po -> po.getInOutType() == 1)
                .collect(Collectors.toList());
        List<String> res = new ArrayList<>();
        for (BaseCrossDirInfoPO dirPo : dirList) {
            Integer dirType = dirPo.getDirType();
            String dirName = BaseEnum.SignalDirectionEnum.getNameByCode(dirType);

            List<CrossTurnInfoPO> turnList = baseCrossTurnInfoMapper.selectByCrossIdAndDir(crossId, dirType);
            for (CrossTurnInfoPO turnPO : turnList) {
                String turnType = turnPO.getTurnType();
                String turnDesc = TurnConvertEnum.getDescByCode(turnType);
                res.add(dirName + "进口" + turnDesc);
            }
        }
        return res;
    }

    private List<String> buildDirMenu(String crossId) {
        List<BaseCrossDirInfoPO> poList = baseCrossDirInfoMapper.selectByCrossId(crossId);
        List<BaseCrossDirInfoPO> filteredList = poList.stream()
                .filter(po -> po.getInOutType() == 1)
                .collect(Collectors.toList());
        List<String> res = new ArrayList<>();
        for (BaseCrossDirInfoPO po : filteredList) {
            Integer dirType = po.getDirType();
            String dirName = BaseEnum.SignalDirectionEnum.getNameByCode(dirType);
            res.add(dirName + "进口");
        }
        return res;
    }


}
